﻿<#
    .SYNOPSIS
    This script will install the AWS PV drivers from AwsPvDriverSetup.msi located in the
    same directory as this script.

    .PARAMETER NoReboot
    Do not reboot the computer automatically to complete installation.  A reboot may still
    be necessary for the drivers to be properly loaded.

    .PARAMETER Quiet
    Install without user interaction.  By specifying the Quiet argument, the user agrees to the
    license agreement which can be viewed by omitting the Quiet argument.

    .PARAMETER VerboseLogging
    Write information to VerboseInstallLog.txt in the current working directory which can be used
    to debug issues with installation.

    .EXAMPLE
    .\install.ps1

    .EXAMPLE
    .\install.ps1 -Quiet -NoReboot -VerboseLogging

    .LEGAL
    Copyright (c) 2018 Amazon Web Services, Inc. All rights reserved.

    .LINK
    https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/xen-drivers-overview.html

    .REMARKS
    This script will return 3010 if -NoReboot is specified and a reboot is required to
    complete installation.
#>

param (
    [Switch]$NoReboot,
    [Switch]$Quiet,
    [Switch]$VerboseLogging
)

$ErrorActionPreference = 'Stop'

function Get-InstallDirectory
{
    $Invocation = (Get-Variable MyInvocation -Scope 1).Value
    Split-Path $Invocation.MyCommand.Path
}

$installDirectory = Get-InstallDirectory
$msiName = "AwsPvDriverSetup.msi"
$msiFullPath = Join-Path $installDirectory $msiName -Resolve

$installArguments = New-Object System.Collections.ArrayList

# .Add() prints out the index of the added element, so we redirect that to nowhere.
$installArguments.Add("/i `"$msiFullPath`"") | Out-Null

if ($NoReboot) {
    $installArguments.Add("/norestart") | Out-Null
}

if($Quiet) {
    $installArguments.Add("/quiet") | Out-Null
}

if($VerboseLogging) {
    $verboseLogPath = ".\VerboseInstallLog.txt"
    $installArguments.Add("/l*v $verboseLogPath") | Out-Null
}

$rc = (Start-Process -FilePath "msiexec.exe" -ArgumentList $installArguments -Wait -PassThru).ExitCode
if ($rc -ne 0) {
    return $rc
}
elseif ($NoReboot) {
    return 3010
}
else {
    return 0
}

# SIG # Begin signature block
# MIIkpgYJKoZIhvcNAQcCoIIklzCCJJMCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUcNaNTNW0bKZD5vgjbfTQiI7j
# E0CgghHbMIIFOzCCAyOgAwIBAgIKYSBNtAAAAAAAJzANBgkqhkiG9w0BAQUFADB/
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSkwJwYDVQQDEyBN
# aWNyb3NvZnQgQ29kZSBWZXJpZmljYXRpb24gUm9vdDAeFw0xMTA0MTUxOTQ1MzNa
# Fw0yMTA0MTUxOTU1MzNaMGwxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2Vy
# dCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xKzApBgNVBAMTIkRpZ2lD
# ZXJ0IEhpZ2ggQXNzdXJhbmNlIEVWIFJvb3QgQ0EwggEiMA0GCSqGSIb3DQEBAQUA
# A4IBDwAwggEKAoIBAQDGzOVz5vvUu+UtLTKm3+WBP8nNJUm2cSrD1ZQ0Z6IKHLBf
# aaZAscS3so/QmKSpQVk609yU1jzbdDikSsxNJYL3SqVTEjju80ltcZF+Y7arpl/D
# pIT4T2JRvvjF7Ns4kuMG5QiRDMQoQVX7y1qJFX5x6DW/TXIJPb46OFBbdzEbjbPH
# JEWap6xtABRaBLe6E+tRCphBQSJOZWGHgUFQpnlcid4ZSlfVLuZdHFMsfpjNGgYW
# pGhz0DQEE1yhcdNafFXbXmThN4cwVgTlEbQpgBLxeTmIogIRfCdmt4i3ePLKCqg4
# qwpkwr9mXZWEwaElHoddGlALIBLMQbtuC1E4uEvLAgMBAAGjgcswgcgwEQYDVR0g
# BAowCDAGBgRVHSAAMAsGA1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB0GA1Ud
# DgQWBBSxPsNpA/i/RwHUmCYaCALvY2QrwzAfBgNVHSMEGDAWgBRi+wohW39DbhHa
# CVRQa/XSlnHxnjBVBgNVHR8ETjBMMEqgSKBGhkRodHRwOi8vY3JsLm1pY3Jvc29m
# dC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNyb3NvZnRDb2RlVmVyaWZSb290LmNy
# bDANBgkqhkiG9w0BAQUFAAOCAgEAIIzBWe1vnGstwUo+dR1FTEFQHL2A6tmwkosG
# KhM/UxaeVjlqimO2eCR59X24uUehCpbC9su9omafBuGs0nkJDv083KwCDHCvPxvs
# eH7U60sFYCbZc2GRIe2waGPglxKrb6AS7dmf0tonPLPkVvnR1IEPcb1CfKaJ3M3V
# vZWiq/GTEX3orDEpqF1mcEGd/HXJ1bMaOSrQhQVQi6yRysSTy3GlnaSUb1gM+m4g
# xAgxtYWdfoH50j3KWxiFbAqG7CIJG6V0NE9/KLyVSqsdtpiwXQmkd3Z+76eOXYT2
# GCTL0W2mw6GcwhB1gP+dMv3mz0M6gvfOj+FyKptit1/tlRo5XC+UbUi3AV8zL7vc
# LXM0iQRCChyLefmj+hfv+qEaEN/gssGV61wMBZc7NT4YiE3bbL8kiY3Ivdifezk6
# JKDV39HzShqX9qZveh+wkKmzrAE5kdNht2TxPlc4A6/OetK1kPWu3DmZ1bY8l+2m
# yxbHfWsqTJCU5kxU/R7NIOzOaJyHWOlhYL7rDsnVGX2f6Xi9DqwhdQePqW7gjGoq
# a5zj52W8vC08bdwE3GdFNjKvBIG8qABuYUyVxVzUjo6fL8EydL29EWUDB83vt14C
# V9qG1BooNK+ISbLPpd2CVm9oqhTiWVT+/+ru7+qScCJggeMlI8CfzA9JsjWqWMM6
# w9kWlBAwggXYMIIEwKADAgECAhABVznfx2xiVuf0Y3KCrPFgMA0GCSqGSIb3DQEB
# CwUAMGwxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNV
# BAsTEHd3dy5kaWdpY2VydC5jb20xKzApBgNVBAMTIkRpZ2lDZXJ0IEVWIENvZGUg
# U2lnbmluZyBDQSAoU0hBMikwHhcNMTcwNjAxMDAwMDAwWhcNMjAwNjA0MTIwMDAw
# WjCCAR0xHTAbBgNVBA8MFFByaXZhdGUgT3JnYW5pemF0aW9uMRMwEQYLKwYBBAGC
# NzwCAQMTAlVTMRkwFwYLKwYBBAGCNzwCAQITCERlbGF3YXJlMRAwDgYDVQQFEwc0
# MTUyOTU0MRgwFgYDVQQJEw80MTAgVGVycnkgQXZlIE4xDjAMBgNVBBETBTk4MTA5
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHU2Vh
# dHRsZTEiMCAGA1UEChMZQW1hem9uIFdlYiBTZXJ2aWNlcywgSW5jLjEUMBIGA1UE
# CxMLRUMyIFdpbmRvd3MxIjAgBgNVBAMTGUFtYXpvbiBXZWIgU2VydmljZXMsIElu
# Yy4wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDIcVfNSR3j5LoUqVUM
# txS4NIJq/qOGQMGnTz95nmtpLOG8nv47GzUxzFkqnFmDxxjV9LUoMd5yZhVWyfEI
# Mv7RsV0RhMZqJ/rutNfwt3r/4htqxDqiUHwNUKtqoHOw0Q2qSyKFbawCUbm/Bf3r
# /ya5ACbEz/abzCivvJsvQoRtflyfCemwF2QuK8aw5c98Ab9xl0/ZJgd+966Bvxjf
# 2VVKWf5pOuQKNo6ncZOU9gtgk8uV8h5yIttFsJP7KpN/hoXZC88EZXzjizSuLhut
# d7TEzBY56Lf9q0giZ+R8iiYQdenkKBGp75uvUqbJV+hjndohgKRZ8EnWQFVvVm2r
# aAZTAgMBAAGjggHBMIIBvTAfBgNVHSMEGDAWgBSP6H7wbTJqAAUjx3CXajqQ/2vq
# 1DAdBgNVHQ4EFgQUpJ202cGjSh7SNUwws5w6QmE9IYUwDgYDVR0PAQH/BAQDAgeA
# MBMGA1UdJQQMMAoGCCsGAQUFBwMDMHsGA1UdHwR0MHIwN6A1oDOGMWh0dHA6Ly9j
# cmwzLmRpZ2ljZXJ0LmNvbS9FVkNvZGVTaWduaW5nU0hBMi1nMS5jcmwwN6A1oDOG
# MWh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9FVkNvZGVTaWduaW5nU0hBMi1nMS5j
# cmwwSwYDVR0gBEQwQjA3BglghkgBhv1sAwIwKjAoBggrBgEFBQcCARYcaHR0cHM6
# Ly93d3cuZGlnaWNlcnQuY29tL0NQUzAHBgVngQwBAzB+BggrBgEFBQcBAQRyMHAw
# JAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBIBggrBgEFBQcw
# AoY8aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0RVZDb2RlU2ln
# bmluZ0NBLVNIQTIuY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQELBQADggEB
# AATn4LxNeqlebC8j+gebBiwGYYbc8mM+5NUpme5SdJHXsOQptpl9jnZFboEVDltn
# xfHEMtebLGqX5kz7weqt5HpWatcjvMTTbZrqOMTVvsrNgcSjJ/VZoaWqmFsu4uHu
# wHXCHyqFUA5BxSqJrMjLLYNh5SE/Z8jQ2BAYnZhahetnz7Od2IoJzNgRqSHM/OXs
# ZrTKsxv+o8qPqUKwhu+5HFHS+fXXvv5iZ9MOLcKTPZYecojbgdZCk+qCYuhyThSR
# 3AUdlRAHHnJyMckNUitEiRNQtxXZ8Su1yBF5BExMdUEFAGCHyXq3zUg5g+6Ou53V
# YmGMJNTIDh77kp10b8usIB4wgga8MIIFpKADAgECAhAD8bThXzqC8RSWeLPX2Edc
# MA0GCSqGSIb3DQEBCwUAMGwxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2Vy
# dCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xKzApBgNVBAMTIkRpZ2lD
# ZXJ0IEhpZ2ggQXNzdXJhbmNlIEVWIFJvb3QgQ0EwHhcNMTIwNDE4MTIwMDAwWhcN
# MjcwNDE4MTIwMDAwWjBsMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQg
# SW5jMRkwFwYDVQQLExB3d3cuZGlnaWNlcnQuY29tMSswKQYDVQQDEyJEaWdpQ2Vy
# dCBFViBDb2RlIFNpZ25pbmcgQ0EgKFNIQTIpMIIBIjANBgkqhkiG9w0BAQEFAAOC
# AQ8AMIIBCgKCAQEAp1P6D7K1E/Fkz4SA/K6ANdG218ejLKwaLKzxhKw6NRI6kpG6
# V+TEyfMvqEg8t9Zu3JciulF5Ya9DLw23m7RJMa5EWD6koZanh08jfsNsZSSQVT6h
# yiN8xULpxHpiRZt93mN0y55jJfiEmpqtRU+ufR/IE8t1m8nh4Yr4CwyY9Mo+0EWq
# eh6lWJM2NL4rLisxWGa0MhCfnfBSoe/oPtN28kBa3PpqPRtLrXawjFzuNrqD6jCo
# TN7xCypYQYiuAImrA9EWgiAiduteVDgSYuHScCTb7R9w0mQJgC3itp3OH/K7IfNs
# 29izGXuKUJ/v7DYKXJq3StMIoDl5/d2/PToJJQIDAQABo4IDWDCCA1QwEgYDVR0T
# AQH/BAgwBgEB/wIBADAOBgNVHQ8BAf8EBAMCAYYwEwYDVR0lBAwwCgYIKwYBBQUH
# AwMwfwYIKwYBBQUHAQEEczBxMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdp
# Y2VydC5jb20wSQYIKwYBBQUHMAKGPWh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNv
# bS9EaWdpQ2VydEhpZ2hBc3N1cmFuY2VFVlJvb3RDQS5jcnQwgY8GA1UdHwSBhzCB
# hDBAoD6gPIY6aHR0cDovL2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0SGlnaEFz
# c3VyYW5jZUVWUm9vdENBLmNybDBAoD6gPIY6aHR0cDovL2NybDQuZGlnaWNlcnQu
# Y29tL0RpZ2lDZXJ0SGlnaEFzc3VyYW5jZUVWUm9vdENBLmNybDCCAcQGA1UdIASC
# AbswggG3MIIBswYJYIZIAYb9bAMCMIIBpDA6BggrBgEFBQcCARYuaHR0cDovL3d3
# dy5kaWdpY2VydC5jb20vc3NsLWNwcy1yZXBvc2l0b3J5Lmh0bTCCAWQGCCsGAQUF
# BwICMIIBVh6CAVIAQQBuAHkAIAB1AHMAZQAgAG8AZgAgAHQAaABpAHMAIABDAGUA
# cgB0AGkAZgBpAGMAYQB0AGUAIABjAG8AbgBzAHQAaQB0AHUAdABlAHMAIABhAGMA
# YwBlAHAAdABhAG4AYwBlACAAbwBmACAAdABoAGUAIABEAGkAZwBpAEMAZQByAHQA
# IABDAFAALwBDAFAAUwAgAGEAbgBkACAAdABoAGUAIABSAGUAbAB5AGkAbgBnACAA
# UABhAHIAdAB5ACAAQQBnAHIAZQBlAG0AZQBuAHQAIAB3AGgAaQBjAGgAIABsAGkA
# bQBpAHQAIABsAGkAYQBiAGkAbABpAHQAeQAgAGEAbgBkACAAYQByAGUAIABpAG4A
# YwBvAHIAcABvAHIAYQB0AGUAZAAgAGgAZQByAGUAaQBuACAAYgB5ACAAcgBlAGYA
# ZQByAGUAbgBjAGUALjAdBgNVHQ4EFgQUj+h+8G0yagAFI8dwl2o6kP9r6tQwHwYD
# VR0jBBgwFoAUsT7DaQP4v0cB1JgmGggC72NkK8MwDQYJKoZIhvcNAQELBQADggEB
# ABkzSgyBMzfbrTbJ5Mk6u7UbLnqi4vRDQheev06hTeGx2+mB3Z8B8uSI1en+Cf0h
# wexdgNLw1sFDwv53K9v515EzzmzVshk75i7WyZNPiECOzeH1fvEPxllWcujrakG9
# HNVG1XxJymY4FcG/4JFwd4fcyY0xyQwpojPtjeKHzYmNPxv/1eAal4t82m37qMay
# OmZrewGzzdimNOwSAauVWKXEU1eoYObnAhKguSNkok27fIElZCG+z+5CGEOXu6U3
# Bq9N/yalTWFL7EZBuGXOuHmeCJYLgYyKO4/HmYyjKm6YbV5hxpa3irlhLZO46w4E
# Q9f1/qbwYtSZaqXBwfBklIAxghI1MIISMQIBATCBgDBsMQswCQYDVQQGEwJVUzEV
# MBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3d3cuZGlnaWNlcnQuY29t
# MSswKQYDVQQDEyJEaWdpQ2VydCBFViBDb2RlIFNpZ25pbmcgQ0EgKFNIQTIpAhAB
# Vznfx2xiVuf0Y3KCrPFgMAkGBSsOAwIaBQCgcDAQBgorBgEEAYI3AgEMMQIwADAZ
# BgkqhkiG9w0BCQMxDAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYB
# BAGCNwIBFTAjBgkqhkiG9w0BCQQxFgQUZkA08sQqPAWef8s2bDFPnjRjVTAwDQYJ
# KoZIhvcNAQEBBQAEggEAOzxF46SKpDJfhxuSbR6JiFG82phN6JmrzbLWWtIZZPW3
# AMYWKp5KYkNFZAaIJveykxe+joUMdDhsaCjIEa+2gedXfEvDfsR7DSvmrQgiQgZo
# 6V/kFH4Vp6+Av0VtILwZqKAxxIpTO6u/cDnk6tIQFX35NcJ9plV1OWrd5QTJX7k2
# 41ooYC/R4WmCHE1zB9RqBB9khJuWr30o2K/Hgx/pFu4YTXQuX9Qjansgdjbudm1E
# JCgKIJ0MkpwN44Z2Vnx0j0UzgZHIEz8c8Qkf6LCKc9LEVh0cNcDNSapjNlimCOqh
# B+tGZrNjY7NzreOajBFyDOTzDYsu4mLWLQ9hrx6KG6GCEBcwghATBgorBgEEAYI3
# AwMBMYIQAzCCD/8GCSqGSIb3DQEHAqCCD/Awgg/sAgEDMQswCQYFKw4DAhoFADBn
# BgsqhkiG9w0BCRABBKBYBFYwVAIBAQYJYIZIAYb9bAcBMCEwCQYFKw4DAhoFAAQU
# JWc4CkD/Dk7UhQONri+Jua5FIpECEHdRDnVcbdet/m8QS6LHRJMYDzIwMTgxMjA2
# MTkyODUzWqCCDT8wggZqMIIFUqADAgECAhADAZoCOv9YsWvW1ermF/BmMA0GCSqG
# SIb3DQEBBQUAMGIxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMx
# GTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xITAfBgNVBAMTGERpZ2lDZXJ0IEFz
# c3VyZWQgSUQgQ0EtMTAeFw0xNDEwMjIwMDAwMDBaFw0yNDEwMjIwMDAwMDBaMEcx
# CzAJBgNVBAYTAlVTMREwDwYDVQQKEwhEaWdpQ2VydDElMCMGA1UEAxMcRGlnaUNl
# cnQgVGltZXN0YW1wIFJlc3BvbmRlcjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCC
# AQoCggEBAKNkXfx8s+CCNeDg9sYq5kl1O8xu4FOpnx9kWeZ8a39rjJ1V+JLjntVa
# Y1sCSVDZg85vZu7dy4XpX6X51Id0iEQ7Gcnl9ZGfxhQ5rCTqqEsskYnMXij0ZLZQ
# t/USs3OWCmejvmGfrvP9Enh1DqZbFP1FI46GRFV9GIYFjFWHeUhG98oOjafeTl/i
# qLYtWQJhiGFyGGi5uHzu5uc0LzF3gTAfuzYBje8n4/ea8EwxZI3j6/oZh6h+z+yM
# DDZbesF6uHjHyQYuRhDIjegEYNu8c3T6Ttj+qkDxss5wRoPp2kChWTrZFQlXmVYw
# k/PJYczQCMxr7GJCkawCwO+k8IkRj3cCAwEAAaOCAzUwggMxMA4GA1UdDwEB/wQE
# AwIHgDAMBgNVHRMBAf8EAjAAMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMIMIIBvwYD
# VR0gBIIBtjCCAbIwggGhBglghkgBhv1sBwEwggGSMCgGCCsGAQUFBwIBFhxodHRw
# czovL3d3dy5kaWdpY2VydC5jb20vQ1BTMIIBZAYIKwYBBQUHAgIwggFWHoIBUgBB
# AG4AeQAgAHUAcwBlACAAbwBmACAAdABoAGkAcwAgAEMAZQByAHQAaQBmAGkAYwBh
# AHQAZQAgAGMAbwBuAHMAdABpAHQAdQB0AGUAcwAgAGEAYwBjAGUAcAB0AGEAbgBj
# AGUAIABvAGYAIAB0AGgAZQAgAEQAaQBnAGkAQwBlAHIAdAAgAEMAUAAvAEMAUABT
# ACAAYQBuAGQAIAB0AGgAZQAgAFIAZQBsAHkAaQBuAGcAIABQAGEAcgB0AHkAIABB
# AGcAcgBlAGUAbQBlAG4AdAAgAHcAaABpAGMAaAAgAGwAaQBtAGkAdAAgAGwAaQBh
# AGIAaQBsAGkAdAB5ACAAYQBuAGQAIABhAHIAZQAgAGkAbgBjAG8AcgBwAG8AcgBh
# AHQAZQBkACAAaABlAHIAZQBpAG4AIABiAHkAIAByAGUAZgBlAHIAZQBuAGMAZQAu
# MAsGCWCGSAGG/WwDFTAfBgNVHSMEGDAWgBQVABIrE5iymQftHt+ivlcNK2cCzTAd
# BgNVHQ4EFgQUYVpNJLZJMp1KKnkag0v0HonByn0wfQYDVR0fBHYwdDA4oDagNIYy
# aHR0cDovL2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEQ0EtMS5j
# cmwwOKA2oDSGMmh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3Vy
# ZWRJRENBLTEuY3JsMHcGCCsGAQUFBwEBBGswaTAkBggrBgEFBQcwAYYYaHR0cDov
# L29jc3AuZGlnaWNlcnQuY29tMEEGCCsGAQUFBzAChjVodHRwOi8vY2FjZXJ0cy5k
# aWdpY2VydC5jb20vRGlnaUNlcnRBc3N1cmVkSURDQS0xLmNydDANBgkqhkiG9w0B
# AQUFAAOCAQEAnSV+GzNNsiaBXJuGziMgD4CH5Yj//7HUaiwx7ToXGXEXzakbvFoW
# OQCd42yE5FpA+94GAYw3+puxnSR+/iCkV61bt5qwYCbqaVchXTQvH3Gwg5QZBWs1
# kBCge5fH9j/n4hFBpr1i2fAnPTgdKG86Ugnw7HBi02JLsOBzppLA044x2C/jbRcT
# Bu7kA7YUq/OPQ6dxnSHdFMoVXZJB2vkPgdGZdA0mxA5/G7X1oPHGdwYoFenYk+VV
# FvC7Cqsc21xIJ2bIo4sKHOWV2q7ELlmgYd3a822iYemKC23sEhi991VUQAOSK2vC
# UcIKSK+w1G7g9BQKOhvjjz3Kr2qNe9zYRDCCBs0wggW1oAMCAQICEAb9+QOWA63q
# AArrPye7uhswDQYJKoZIhvcNAQEFBQAwZTELMAkGA1UEBhMCVVMxFTATBgNVBAoT
# DERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTEkMCIGA1UE
# AxMbRGlnaUNlcnQgQXNzdXJlZCBJRCBSb290IENBMB4XDTA2MTExMDAwMDAwMFoX
# DTIxMTExMDAwMDAwMFowYjELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0
# IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTEhMB8GA1UEAxMYRGlnaUNl
# cnQgQXNzdXJlZCBJRCBDQS0xMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
# AQEA6IItmfnKwkKVpYBzQHDSnlZUXKnE0kEGj8kz/E1FkVyBn+0snPgWWd+etSQV
# wpi5tHdJ3InECtqvy15r7a2wcTHrzzpADEZNk+yLejYIA6sMNP4YSYL+x8cxSIB8
# HqIPkg5QycaH6zY/2DDD/6b3+6LNb3Mj/qxWBZDwMiEWicZwiPkFl32jx0PdAug7
# Pe2xQaPtP77blUjE7h6z8rwMK5nQxl0SQoHhg26Ccz8mSxSQrllmCsSNvtLOBq6t
# hG9IhJtPQLnxTPKvmPv2zkBdXPao8S+v7Iki8msYZbHBc63X8djPHgp0XEK4aH63
# 1XcKJ1Z8D2KkPzIUYJX9BwSiCQIDAQABo4IDejCCA3YwDgYDVR0PAQH/BAQDAgGG
# MDsGA1UdJQQ0MDIGCCsGAQUFBwMBBggrBgEFBQcDAgYIKwYBBQUHAwMGCCsGAQUF
# BwMEBggrBgEFBQcDCDCCAdIGA1UdIASCAckwggHFMIIBtAYKYIZIAYb9bAABBDCC
# AaQwOgYIKwYBBQUHAgEWLmh0dHA6Ly93d3cuZGlnaWNlcnQuY29tL3NzbC1jcHMt
# cmVwb3NpdG9yeS5odG0wggFkBggrBgEFBQcCAjCCAVYeggFSAEEAbgB5ACAAdQBz
# AGUAIABvAGYAIAB0AGgAaQBzACAAQwBlAHIAdABpAGYAaQBjAGEAdABlACAAYwBv
# AG4AcwB0AGkAdAB1AHQAZQBzACAAYQBjAGMAZQBwAHQAYQBuAGMAZQAgAG8AZgAg
# AHQAaABlACAARABpAGcAaQBDAGUAcgB0ACAAQwBQAC8AQwBQAFMAIABhAG4AZAAg
# AHQAaABlACAAUgBlAGwAeQBpAG4AZwAgAFAAYQByAHQAeQAgAEEAZwByAGUAZQBt
# AGUAbgB0ACAAdwBoAGkAYwBoACAAbABpAG0AaQB0ACAAbABpAGEAYgBpAGwAaQB0
# AHkAIABhAG4AZAAgAGEAcgBlACAAaQBuAGMAbwByAHAAbwByAGEAdABlAGQAIABo
# AGUAcgBlAGkAbgAgAGIAeQAgAHIAZQBmAGUAcgBlAG4AYwBlAC4wCwYJYIZIAYb9
# bAMVMBIGA1UdEwEB/wQIMAYBAf8CAQAweQYIKwYBBQUHAQEEbTBrMCQGCCsGAQUF
# BzABhhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wQwYIKwYBBQUHMAKGN2h0dHA6
# Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3VyZWRJRFJvb3RDQS5j
# cnQwgYEGA1UdHwR6MHgwOqA4oDaGNGh0dHA6Ly9jcmwzLmRpZ2ljZXJ0LmNvbS9E
# aWdpQ2VydEFzc3VyZWRJRFJvb3RDQS5jcmwwOqA4oDaGNGh0dHA6Ly9jcmw0LmRp
# Z2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3VyZWRJRFJvb3RDQS5jcmwwHQYDVR0OBBYE
# FBUAEisTmLKZB+0e36K+Vw0rZwLNMB8GA1UdIwQYMBaAFEXroq/0ksuCMS1Ri6en
# IZ3zbcgPMA0GCSqGSIb3DQEBBQUAA4IBAQBGUD7Jtygkpzgdtlspr1LPUukxR6tW
# XHvVDQtBs+/sdR90OPKyXGGinJXDUOSCuSPRujqGcq04eKx1XRcXNHJHhZRW0eu7
# NoR3zCSl8wQZVann4+erYs37iy2QwsDStZS9Xk+xBdIOPRqpFFumhjFiqKgz5Js5
# p8T1zh14dpQlc+Qqq8+cdkvtX8JLFuRLcEwAiR78xXm8TBJX/l/hHrwCXaj++wc4
# Tw3GXZG5D2dFzdaD7eeSDY2xaYxP+1ngIw/Sqq4AfO6cQg7PkdcntxbuD8O9fAqg
# 7iwIVYUiuOsYGk38KiGtSTGDR5V3cdyxG0tLHBCcdxTBnU8vWpUIKRAmMYICLDCC
# AigCAQEwdjBiMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkw
# FwYDVQQLExB3d3cuZGlnaWNlcnQuY29tMSEwHwYDVQQDExhEaWdpQ2VydCBBc3N1
# cmVkIElEIENBLTECEAMBmgI6/1ixa9bV6uYX8GYwCQYFKw4DAhoFAKCBjDAaBgkq
# hkiG9w0BCQMxDQYLKoZIhvcNAQkQAQQwHAYJKoZIhvcNAQkFMQ8XDTE4MTIwNjE5
# Mjg1M1owIwYJKoZIhvcNAQkEMRYEFN0ncnFYZazYOVUXGFeFsiRsFZ9wMCsGCyqG
# SIb3DQEJEAIMMRwwGjAYMBYEFGFNJx2RAuMBaYIkh/3l3gCjUrAdMA0GCSqGSIb3
# DQEBAQUABIIBAHfYI88US2pD72TO8piqN1Dp0l+pTotK5FUwv9XdCU/VHZABKwxN
# 74lMPiSgEN83bF+5KaBuK+RME5rntI3N3EujFiNHlHB4CSGyT+hCx6lAm63k6pHC
# z2fjh2wvzwBKSTrjcT0/Z8AvL4/oN2FSl8/SzK383rEJxZi0XKVg2ZlISrsj3Xeo
# X21FhoKdvlpS9LJb/YIKK22Uf54C3Mju/ZFtoB1mnIIQ0ff8lSh/pOqz8PegJWgY
# jGAnaGC8wWEOgJ2yQkaw/hfWQ05Ndj5rXhglcYMJyNoyOjIw9rb6EFiSs4Kdfyu/
# ASYZPaN1Kha1m56O86g8vwdOeB2OMauht1s=
# SIG # End signature block
